# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list import PaginatedansibleCollectionVersionResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedansibleCollectionVersionResponseList(unittest.TestCase):
    """PaginatedansibleCollectionVersionResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedansibleCollectionVersionResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginatedansible_collection_version_response_list.PaginatedansibleCollectionVersionResponseList()  # noqa: E501
        if include_optional :
            return PaginatedansibleCollectionVersionResponseList(
                count = 123, 
                next = 'http://api.example.org/accounts/?offset=400&limit=100', 
                previous = 'http://api.example.org/accounts/?offset=200&limit=100', 
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/collection_version_response.ansible.CollectionVersionResponse(
                        artifact = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_href = '0', 
                        md5 = '0', 
                        sha1 = '0', 
                        sha224 = '0', 
                        sha256 = '0', 
                        sha384 = '0', 
                        sha512 = '0', 
                        id = '0', 
                        authors = [
                            '0'
                            ], 
                        contents = [
                            None
                            ], 
                        dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                        description = '0', 
                        docs_blob = pulpcore.client.pulp_ansible.models.docs_blob.docs_blob(), 
                        manifest = pulpcore.client.pulp_ansible.models.manifest.manifest(), 
                        files = pulpcore.client.pulp_ansible.models.files.files(), 
                        documentation = '0', 
                        homepage = '0', 
                        issues = '0', 
                        license = [
                            '0'
                            ], 
                        name = '0', 
                        namespace = '0', 
                        repository = '0', 
                        tags = [
                            pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                                name = '0', )
                            ], 
                        version = '0', 
                        requires_ansible = '0', )
                    ]
            )
        else :
            return PaginatedansibleCollectionVersionResponseList(
        )

    def testPaginatedansibleCollectionVersionResponseList(self):
        """Test PaginatedansibleCollectionVersionResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
