# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class ArtifactRefResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'filename': 'str',
        'sha256': 'str',
        'size': 'int'
    }

    attribute_map = {
        'filename': 'filename',
        'sha256': 'sha256',
        'size': 'size'
    }

    def __init__(self, filename=None, sha256=None, size=None, local_vars_configuration=None):  # noqa: E501
        """ArtifactRefResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._filename = None
        self._sha256 = None
        self._size = None
        self.discriminator = None

        self.filename = filename
        self.sha256 = sha256
        self.size = size

    @property
    def filename(self):
        """Gets the filename of this ArtifactRefResponse.  # noqa: E501


        :return: The filename of this ArtifactRefResponse.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this ArtifactRefResponse.


        :param filename: The filename of this ArtifactRefResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and filename is None:  # noqa: E501
            raise ValueError("Invalid value for `filename`, must not be `None`")  # noqa: E501

        self._filename = filename

    @property
    def sha256(self):
        """Gets the sha256 of this ArtifactRefResponse.  # noqa: E501


        :return: The sha256 of this ArtifactRefResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this ArtifactRefResponse.


        :param sha256: The sha256 of this ArtifactRefResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sha256 is None:  # noqa: E501
            raise ValueError("Invalid value for `sha256`, must not be `None`")  # noqa: E501

        self._sha256 = sha256

    @property
    def size(self):
        """Gets the size of this ArtifactRefResponse.  # noqa: E501


        :return: The size of this ArtifactRefResponse.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ArtifactRefResponse.


        :param size: The size of this ArtifactRefResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArtifactRefResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ArtifactRefResponse):
            return True

        return self.to_dict() != other.to_dict()
